% material types
air=1;
ferrite=3;
copper=2;

% dimensions
cm = 0.01;
mm = 0.001;

% set up initial geometry
xmin=0.0; dx=0.5*cm; nx=20;
xmax=xmin+dx*nx;
ymin=0.0; dy=0.5*cm; ny=20;
ymax=ymin+dy*ny;
[nl,tl]=create_lists(xmin,dx,nx,ymin,dy,ny);

% describe geometry
x0=0.0;
x1=2*cm;
x2=x1+1*cm;
y0=0.0;
y1=2*cm;
y2=5*cm;

corex=[x0 x0 x1 x1 x0];
corey=[y0 y2 y2 y0 y0];
windx=[x1 x1 x2 x2 x1];
windy=[y0 y1 y1 y0 y0];

% change materials
tl=change_rectangle(nl,tl,x0,x1,y0,y2,0.1*mm,ferrite,0.0);
tl=change_rectangle(nl,tl,x1,x2,y0,y1,0.1*mm,copper,1e4);

% establish boundary conditioins
nl=x_dirichlet(nl,xmin,0.1*mm);
nl=x_dirichlet(nl,xmax,0.1*mm);
nl=y_dirichlet(nl,ymax,0.1*mm);

% stretch the grid
nl=x_pstretch(nl,6*cm,1.0,50.0,2);
nl=y_pstretch(nl,6*cm,1.0,50.0,2);

% plot the grid
figure(2);
plot_triangles(nl,tl);
hold on;
plot_nodes(nl);
hold off;
axis([min(nl.x) max(nl.x) min(nl.y) max(nl.y)]);

% solve for the magnetic potential
[nl,tl]=compute_fields(nl,tl,@mub);

% plot the energy field
figure(3)
plot_by_domains(nl,tl,[],[],tl.e);
hold on;
plot_lines(nl,tl,10);
hold on;
plot(corex,corey,'g',windx,windy,'g');
hold off;
title('Energy Density J/m^3');
xlabel('x,m');
ylabel('y,m');

% compute the flux density
figure(4)
plot_by_domains(nl,tl,tl.bm,[],[]);
hold on;
plot_lines(nl,tl,10);
hold on;
plot(corex,corey,'g',windx,windy,'g');
hold off;
title('Flux Density T');
xlabel('x,m');
ylabel('y,m');

% compute the flux density
figure(5)
plot_by_domains(nl,tl,[],tl.hm,[]);
hold on;
plot_lines(nl,tl,10);
hold on;
plot(corex,corey,'g',windx,windy,'g');
hold off;
title('Field Intensity A/m');
xlabel('x,m');
ylabel('y,m');